@@ -16,12 +16,14 @@
 /* Description:  This file implements debug fs related functions. */
 
 #include <linux/debugfs.h>
+#include <linux/etherdevice.h>
 
 #include "sysadpt.h"
-#include "dev.h"
-#include "hostcmd.h"
-#include "fwcmd.h"
+#include "core.h"
+#include "utils.h"
 #include "thermal.h"
+#include "hif/fwcmd.h"
+#include "hif/hif-ops.h"
 #include "debugfs.h"
 
 #define MWLWIFI_DEBUGFS_ADD_FILE(name) do { \
@@ -96,13 +98,15 @@ static ssize_t mwl_debugfs_info_read(struct file *file, char __user *ubuf,
 
 	len += scnprintf(p + len, size - len, "\n");
 	len += scnprintf(p + len, size - len,
-			 "driver name: %s\n", MWL_DRV_NAME);
+			 "driver name: %s\n",
+			 mwl_hif_get_driver_name(priv->hw));
 	len += scnprintf(p + len, size - len, "chip type: %s\n",
 			 chipname[priv->chip_type]);
 	len += scnprintf(p + len, size - len,
 			 "hw version: %X\n", priv->hw_data.hw_version);
 	len += scnprintf(p + len, size - len,
-			 "driver version: %s\n", MWL_DRV_VERSION);
+			 "driver version: %s\n",
+			 mwl_hif_get_driver_version(priv->hw));
 	len += scnprintf(p + len, size - len, "firmware version: 0x%08x\n",
 			 priv->hw_data.fw_release_num);
 	len += scnprintf(p + len, size - len,
@@ -124,14 +128,9 @@ static ssize_t mwl_debugfs_info_read(struct file *file, char __user *ubuf,
 		rx_num = 2;
 	else if (priv->antenna_rx == ANTENNA_RX_3)
 		rx_num = 3;
-	len += scnprintf(p + len, size - len, "antenna: %d %d\n", tx_num, rx_num);
+	len += scnprintf(p + len, size - len, "antenna: %d %d\n",
+			 tx_num, rx_num);
 	len += scnprintf(p + len, size - len, "irq number: %d\n", priv->irq);
-	len += scnprintf(p + len, size - len, "iobase0: %p\n", priv->iobase0);
-	len += scnprintf(p + len, size - len, "iobase1: %p\n", priv->iobase1);
-	len += scnprintf(p + len, size - len,
-			 "tx limit: %d\n", priv->txq_limit);
-	len += scnprintf(p + len, size - len,
-			 "rx limit: %d\n", priv->recv_limit);
 	len += scnprintf(p + len, size - len, "ap macid support: %08x\n",
 			 priv->ap_macids_supported);
 	len += scnprintf(p + len, size - len, "sta macid support: %08x\n",
@@ -139,7 +138,52 @@ static ssize_t mwl_debugfs_info_read(struct file *file, char __user *ubuf,
 	len += scnprintf(p + len, size - len,
 			 "macid used: %08x\n", priv->macids_used);
 	len += scnprintf(p + len, size - len,
-			 "qe trigger number: %d\n", priv->qe_trigger_num);
+			 "radio: %s\n", priv->radio_on ? "enable" : "disable");
+	len += mwl_hif_get_info(priv->hw, p + len, size - len);
+	len += scnprintf(p + len, size - len, "\n");
+
+	ret = simple_read_from_buffer(ubuf, count, ppos, p, len);
+	free_page(page);
+
+	return ret;
+}
+
+static ssize_t mwl_debugfs_tx_status_read(struct file *file, char __user *ubuf,
+					  size_t count, loff_t *ppos)
+{
+	struct mwl_priv *priv = (struct mwl_priv *)file->private_data;
+	unsigned long page = get_zeroed_page(GFP_KERNEL);
+	char *p = (char *)page;
+	int len = 0, size = PAGE_SIZE;
+	ssize_t ret;
+
+	if (!p)
+		return -ENOMEM;
+
+	len += scnprintf(p + len, size - len, "\n");
+	len += mwl_hif_get_tx_status(priv->hw, p + len, size - len);
+	len += scnprintf(p + len, size - len, "\n");
+
+	ret = simple_read_from_buffer(ubuf, count, ppos, p, len);
+	free_page(page);
+
+	return ret;
+}
+
+static ssize_t mwl_debugfs_rx_status_read(struct file *file, char __user *ubuf,
+					  size_t count, loff_t *ppos)
+{
+	struct mwl_priv *priv = (struct mwl_priv *)file->private_data;
+	unsigned long page = get_zeroed_page(GFP_KERNEL);
+	char *p = (char *)page;
+	int len = 0, size = PAGE_SIZE;
+	ssize_t ret;
+
+	if (!p)
+		return -ENOMEM;
+
+	len += scnprintf(p + len, size - len, "\n");
+	len += mwl_hif_get_rx_status(priv->hw, p + len, size - len);
 	len += scnprintf(p + len, size - len, "\n");
 
 	ret = simple_read_from_buffer(ubuf, count, ppos, p, len);
@@ -166,8 +210,8 @@ static ssize_t mwl_debugfs_vif_read(struct file *file, char __user *ubuf,
 	len += scnprintf(p + len, size - len, "\n");
 	spin_lock_bh(&priv->vif_lock);
 	list_for_each_entry(mwl_vif, &priv->vif_list, list) {
-		vif = container_of((char *)mwl_vif, struct ieee80211_vif,
-				   drv_priv[0]);
+		vif = container_of((void *)mwl_vif, struct ieee80211_vif,
+				   drv_priv);
 		len += scnprintf(p + len, size - len,
 				 "macid: %d\n", mwl_vif->macid);
 		switch (vif->type) {
@@ -237,8 +281,8 @@ static ssize_t mwl_debugfs_sta_read(struct file *file, char __user *ubuf,
 	len += scnprintf(p + len, size - len, "\n");
 	spin_lock_bh(&priv->sta_lock);
 	list_for_each_entry(sta_info, &priv->sta_list, list) {
-		sta = container_of((char *)sta_info, struct ieee80211_sta,
-				   drv_priv[0]);
+		sta = container_of((void *)sta_info, struct ieee80211_sta,
+				   drv_priv);
 		len += scnprintf(p + len, size - len,
 				 "mac address: %pM\n", sta->addr);
 		len += scnprintf(p + len, size - len, "aid: %u\n", sta->aid);
@@ -308,8 +352,10 @@ static ssize_t mwl_debugfs_ampdu_read(struct file *file, char __user *ubuf,
 
 	len += scnprintf(p + len, size - len, "\n");
 	spin_lock_bh(&priv->stream_lock);
-	for (i = 0; i < SYSADPT_TX_AMPDU_QUEUES; i++) {
+	for (i = 0; i < priv->ampdu_num; i++) {
 		stream = &priv->ampdu[i];
+		if (!stream->state)
+			continue;
 		len += scnprintf(p + len, size - len, "stream: %d\n", i);
 		len += scnprintf(p + len, size - len, "idx: %u\n", stream->idx);
 		len += scnprintf(p + len, size - len,
@@ -327,9 +373,9 @@ static ssize_t mwl_debugfs_ampdu_read(struct file *file, char __user *ubuf,
 	list_for_each_entry(sta_info, &priv->sta_list, list) {
 		for (i = 0; i < MWL_MAX_TID; i++) {
 			if (sta_info->check_ba_failed[i]) {
-				sta = container_of((char *)sta_info,
+				sta = container_of((void *)sta_info,
 						   struct ieee80211_sta,
-						   drv_priv[0]);
+						   drv_priv);
 				len += scnprintf(p + len, size - len,
 						 "%pM(%d): %d\n",
 						 sta->addr, i,
@@ -346,6 +392,39 @@ static ssize_t mwl_debugfs_ampdu_read(struct file *file, char __user *ubuf,
 	return ret;
 }
 
+static ssize_t mwl_debugfs_stnid_read(struct file *file, char __user *ubuf,
+				      size_t count, loff_t *ppos)
+{
+	struct mwl_priv *priv = (struct mwl_priv *)file->private_data;
+	unsigned long page = get_zeroed_page(GFP_KERNEL);
+	char *p = (char *)page;
+	int len = 0, size = PAGE_SIZE;
+	struct mwl_stnid *stnid;
+	int i;
+	ssize_t ret;
+
+	if (!p)
+		return -ENOMEM;
+
+	len += scnprintf(p + len, size - len, "\n");
+	spin_lock_bh(&priv->stnid_lock);
+	for (i = 0; i < priv->stnid_num; i++) {
+		stnid = &priv->stnid[i];
+		if (!stnid->aid)
+			continue;
+		len += scnprintf(p + len, size - len,
+				 "stnid: %d macid: %d aid: %d\n",
+				 i + 1, stnid->macid, stnid->aid);
+	}
+	spin_unlock_bh(&priv->stnid_lock);
+	len += scnprintf(p + len, size - len, "\n");
+
+	ret = simple_read_from_buffer(ubuf, count, ppos, p, len);
+	free_page(page);
+
+	return ret;
+}
+
 static ssize_t mwl_debugfs_device_pwrtbl_read(struct file *file,
 					      char __user *ubuf,
 					      size_t count, loff_t *ppos)
@@ -389,79 +468,6 @@ static ssize_t mwl_debugfs_device_pwrtbl_read(struct file *file,
 	return ret;
 }
 
-static ssize_t mwl_debugfs_tx_desc_read(struct file *file,
-					char __user *ubuf,
-					size_t count, loff_t *ppos)
-{
-	struct mwl_priv *priv = (struct mwl_priv *)file->private_data;
-	unsigned long page = get_zeroed_page(GFP_KERNEL);
-	char *p = (char *)page;
-	int len = 0, size = PAGE_SIZE;
-	struct mwl_desc_data *desc;
-	int i, num, write_item = -1, free_item = -1;
-	ssize_t ret;
-
-	spin_lock_bh(&priv->tx_desc_lock);
-	num = priv->tx_desc_num;
-	desc = &priv->desc_data[num];
-	len += scnprintf(p + len, size - len, "num: %i fw_desc_cnt:%i\n",
-			 num, priv->fw_desc_cnt[num]);
-	for (i = 0; i < SYSADPT_MAX_NUM_TX_DESC; i++) {
-		len += scnprintf(p + len, size - len, "%3i %x\n", i,
-				 desc->tx_hndl[i].pdesc->status);
-		if (desc->pnext_tx_hndl == &desc->tx_hndl[i])
-			write_item = i;
-		if (desc->pstale_tx_hndl == &desc->tx_hndl[i])
-			free_item = i;
-	}
-	len += scnprintf(p + len, size - len, "next:%i stale:%i\n",
-			 write_item, free_item);
-	len += scnprintf(p + len, size - len, "\n");
-	spin_unlock_bh(&priv->tx_desc_lock);
-
-	ret = simple_read_from_buffer(ubuf, count, ppos, p, len);
-	free_page(page);
-
-	return ret;
-}
-
-static ssize_t mwl_debugfs_tx_desc_write(struct file *file,
-					 const char __user *ubuf,
-					 size_t count, loff_t *ppos)
-{
-	struct mwl_priv *priv = (struct mwl_priv *)file->private_data;
-	unsigned long addr = get_zeroed_page(GFP_KERNEL);
-	char *buf = (char *)addr;
-	size_t buf_size = min_t(size_t, count, PAGE_SIZE - 1);
-	int tx_desc_num = 0;
-	ssize_t ret;
-
-	if (!buf)
-		return -ENOMEM;
-
-	if (copy_from_user(buf, ubuf, buf_size)) {
-		ret = -EFAULT;
-		goto err;
-	}
-
-	if (kstrtoint(buf, 0, &tx_desc_num)) {
-		ret = -EINVAL;
-		goto err;
-	}
-
-	if ((tx_desc_num < 0) || (tx_desc_num >= SYSADPT_NUM_OF_DESC_DATA)) {
-		ret = -EINVAL;
-		goto err;
-	}
-
-	priv->tx_desc_num = tx_desc_num;
-	ret = count;
-
-err:
-	free_page(addr);
-	return ret;
-}
-
 static ssize_t mwl_debugfs_dfs_channel_read(struct file *file,
 					    char __user *ubuf,
 					    size_t count, loff_t *ppos)
@@ -479,8 +485,10 @@ static ssize_t mwl_debugfs_dfs_channel_read(struct file *file,
 		return -ENOMEM;
 
 	sband = priv->hw->wiphy->bands[NL80211_BAND_5GHZ];
-	if (!sband)
-		return -EINVAL;
+	if (!sband) {
+		ret = -EINVAL;
+		goto err;
+	}
 
 	len += scnprintf(p + len, size - len, "\n");
 	for (i = 0; i < sband->n_channels; i++) {
@@ -499,8 +507,9 @@ static ssize_t mwl_debugfs_dfs_channel_read(struct file *file,
 	len += scnprintf(p + len, size - len, "\n");
 
 	ret = simple_read_from_buffer(ubuf, count, ppos, p, len);
-	free_page(page);
 
+err:
+	free_page(page);
 	return ret;
 }
 
@@ -673,67 +682,6 @@ err:
 	return ret;
 }
 
-
-static int mwl_debugfs_reg_access(struct mwl_priv *priv, bool write)
-{
-	struct ieee80211_hw *hw = priv->hw;
-	u8 set;
-	u32 *addr_val;
-	int ret = 0;
-
-	set = write ? WL_SET : WL_GET;
-
-	switch (priv->reg_type) {
-	case MWL_ACCESS_RF:
-		ret = mwl_fwcmd_reg_rf(hw, set, priv->reg_offset,
-				       &priv->reg_value);
-		break;
-	case MWL_ACCESS_BBP:
-		ret = mwl_fwcmd_reg_bb(hw, set, priv->reg_offset,
-				       &priv->reg_value);
-		break;
-	case MWL_ACCESS_CAU:
-		ret = mwl_fwcmd_reg_cau(hw, set, priv->reg_offset,
-					&priv->reg_value);
-		break;
-	case MWL_ACCESS_ADDR0:
-		if (set == WL_GET)
-			priv->reg_value =
-				readl(priv->iobase0 + priv->reg_offset);
-		else
-			writel(priv->reg_value,
-			       priv->iobase0 + priv->reg_offset);
-		break;
-	case MWL_ACCESS_ADDR1:
-		if (set == WL_GET)
-			priv->reg_value =
-				readl(priv->iobase1 + priv->reg_offset);
-		else
-			writel(priv->reg_value,
-			       priv->iobase1 + priv->reg_offset);
-		break;
-	case MWL_ACCESS_ADDR:
-		addr_val = kmalloc(64 * sizeof(u32), GFP_KERNEL);
-		if (addr_val) {
-			memset(addr_val, 0, 64 * sizeof(u32));
-			addr_val[0] = priv->reg_value;
-			ret = mwl_fwcmd_get_addr_value(hw, priv->reg_offset,
-						       4, addr_val, set);
-			if ((!ret) && (set == WL_GET))
-				priv->reg_value = addr_val[0];
-			kfree(addr_val);
-		} else {
-			ret = -ENOMEM;
-		}
-		break;
-	default:
-		ret = -EINVAL;
-		break;
-	}
-
-	return ret;
-}
-
 static ssize_t mwl_debugfs_regrdwr_read(struct file *file, char __user *ubuf,
 					size_t count, loff_t *ppos)
 {
@@ -741,7 +689,10 @@ static ssize_t mwl_debugfs_regrdwr_read(struct file *file, char __user *ubuf,
 	unsigned long page = get_zeroed_page(GFP_KERNEL);
 	char *p = (char *)page;
 	int len = 0, size = PAGE_SIZE;
-	int ret = 0;
+	ssize_t ret;
+
+	if (*ppos)
+		return len;
 
 	if (!p)
 		return -ENOMEM;
@@ -749,16 +700,17 @@ static ssize_t mwl_debugfs_regrdwr_read(struct file *file, char __user *ubuf,
 	if (!priv->reg_type) {
 		/* No command has been given */
 		len += scnprintf(p + len, size - len, "0");
+		ret = -EINVAL;
 		goto none;
 	}
 
 	/* Set command has been given */
 	if (priv->reg_value != UINT_MAX) {
-		ret = mwl_debugfs_reg_access(priv, true);
+		ret = mwl_hif_reg_access(priv->hw, true);
 		goto done;
 	}
 	/* Get command has been given */
-	ret = mwl_debugfs_reg_access(priv, false);
+	ret = mwl_hif_reg_access(priv->hw, false);
 
 done:
 	if (!ret)
@@ -774,7 +726,6 @@ done:
 	ret = simple_read_from_buffer(ubuf, count, ppos, p, len);
 
 none:
-
 	free_page(page);
 	return ret;
 }
@@ -787,7 +738,7 @@ static ssize_t mwl_debugfs_regrdwr_write(struct file *file,
 	unsigned long addr = get_zeroed_page(GFP_KERNEL);
 	char *buf = (char *)addr;
 	size_t buf_size = min_t(size_t, count, PAGE_SIZE - 1);
-	int ret;
+	ssize_t ret;
 	u32 reg_type = 0, reg_offset = 0, reg_value = UINT_MAX;
 
 	if (!buf)
@@ -795,36 +746,190 @@ static ssize_t mwl_debugfs_regrdwr_write(struct file *file,
 
 	if (copy_from_user(buf, ubuf, buf_size)) {
 		ret = -EFAULT;
-		goto done;
+		goto err;
 	}
 
 	ret = sscanf(buf, "%u %x %x", &reg_type, &reg_offset, &reg_value);
 
 	if (!reg_type) {
 		ret = -EINVAL;
-		goto done;
+		goto err;
 	} else {
 		priv->reg_type = reg_type;
 		priv->reg_offset = reg_offset;
 		priv->reg_value = reg_value;
 		ret = count;
 	}
-done:
 
+err:
+	free_page(addr);
+	return ret;
+}
+
+static ssize_t mwl_debugfs_ratetable_read(struct file *file, char __user *ubuf,
+					  size_t count, loff_t *ppos)
+{
+	struct mwl_priv *priv = (struct mwl_priv *)file->private_data;
+	unsigned long page = get_zeroed_page(GFP_KERNEL);
+	char *p = (char *)page;
+	int len = 0, size = PAGE_SIZE;
+	struct mwl_sta *sta_info;
+	struct ieee80211_sta *sta;
+	u8 addr[ETH_ALEN];
+	int table_size = (sizeof(__le32) * 2 * SYSADPT_MAX_RATE_ADAPT_RATES);
+	u8 *rate_table;
+	u32 rate_info;
+	u8 fmt, stbc, bw, sgi, mcs, preamble_gf, power_id, ldpc, bf, ant;
+	int idx, rate, nss;
+	ssize_t ret;
+
+	if (!p)
+		return -ENOMEM;
+
+	if (!priv->sta_aid) {
+		ret = -EINVAL;
+		goto err;
+	}
+
+	spin_lock_bh(&priv->sta_lock);
+	list_for_each_entry(sta_info, &priv->sta_list, list) {
+		sta = container_of((void *)sta_info, struct ieee80211_sta,
+				   drv_priv);
+		if (priv->sta_aid == sta->aid) {
+			ether_addr_copy(addr, sta->addr);
+			break;
+		}
+	}
+	spin_unlock_bh(&priv->sta_lock);
+
+	rate_table = kzalloc(size, GFP_KERNEL);
+	if (!rate_table) {
+		ret = -ENOMEM;
+		goto err;
+	}
+
+	ret = mwl_fwcmd_get_ratetable(priv->hw, addr, rate_table,
+				      table_size, 0);
+	if (ret)
+		goto err;
+
+	len += scnprintf(p + len, size - len, "\n");
+	len += scnprintf(p + len, size - len,
+		"%3s %6s %5s %5s %5s %5s %5s %4s %2s %5s %4s %5s %5s\n",
+		"Num", "Fmt", "STBC", "BW", "SGI", "Nss", "RateId",
+		"GF/Pre", "PId", "LDPC", "BF", "TxAnt", "Rate");
+	idx = 0;
+	rate_info = le32_to_cpu(*(__le32 *)rate_table);
+	while (rate_info != 0) {
+		fmt = rate_info & MWL_TX_RATE_FORMAT_MASK;
+		stbc = (rate_info & MWL_TX_RATE_STBC_MASK) >>
+			MWL_TX_RATE_STBC_SHIFT;
+		bw = (rate_info & MWL_TX_RATE_BANDWIDTH_MASK) >>
+			MWL_TX_RATE_BANDWIDTH_SHIFT;
+		sgi = (rate_info & MWL_TX_RATE_SHORTGI_MASK) >>
+			MWL_TX_RATE_SHORTGI_SHIFT;
+		mcs = (rate_info & MWL_TX_RATE_RATEIDMCS_MASK) >>
+			MWL_TX_RATE_RATEIDMCS_SHIFT;
+		preamble_gf = (rate_info & MWL_TX_RATE_PREAMBLE_MASK) >>
+			MWL_TX_RATE_PREAMBLE_SHIFT;
+		power_id = (rate_info & MWL_TX_RATE_POWERID_MASK) >>
+			MWL_TX_RATE_POWERID_SHIFT;
+		ldpc = (rate_info & MWL_TX_RATE_ADVCODING_MASK) >>
+			MWL_TX_RATE_ADVCODING_SHIFT;
+		bf = (rate_info & MWL_TX_RATE_BF_MASK) >>
+			MWL_TX_RATE_BF_SHIFT;
+		ant = (rate_info & MWL_TX_RATE_ANTSELECT_MASK) >>
+			MWL_TX_RATE_ANTSELECT_SHIFT;
+
+		if (fmt == TX_RATE_FORMAT_11AC) {
+			rate = mcs & 0xf; /* 11ac, mcs[3:0]: rate      */
+			nss = mcs >> 4;   /* 11ac, mcs[6:4] = nss code */
+			nss++;  /* ddd 1 to correct Nss representation */
+		} else {
+			rate = mcs;
+			nss = 0;
+			if (fmt == TX_RATE_FORMAT_11N) {
+				if ((mcs >= 0) && (mcs < 8))
+					nss = 1;
+				else if ((mcs >= 8) && (mcs < 16))
+					nss = 2;
+				else if ((mcs >= 16) && (mcs < 24))
+					nss = 3;
+			}
+		}
+
+		len += scnprintf(p + len, size - len,
+			"%3d %5d %5d %5d %5d %5d %5d %5d %5d %5d %5d %5d %5d\n",
+			idx, (int)fmt, (int)stbc, (int)bw, (int)sgi, nss, rate,
+			(int)preamble_gf, (int)power_id, (int)ldpc, (int)bf,
+			(int)ant,
+			utils_get_phy_rate(fmt, bw, sgi, mcs));
+
+		idx++;
+		rate_table += (2 * sizeof(__le32));
+		rate_info = le32_to_cpu(*(__le32 *)rate_table);
+	}
+	len += scnprintf(p + len, size - len, "\n");
+
+	ret = simple_read_from_buffer(ubuf, count, ppos, p, len);
+
+err:
+	free_page(page);
+	return ret;
+}
+
+static ssize_t mwl_debugfs_ratetable_write(struct file *file,
+					   const char __user *ubuf,
+					   size_t count, loff_t *ppos)
+{
+	struct mwl_priv *priv = (struct mwl_priv *)file->private_data;
+	unsigned long addr = get_zeroed_page(GFP_KERNEL);
+	char *buf = (char *)addr;
+	size_t buf_size = min_t(size_t, count, PAGE_SIZE - 1);
+	int sta_aid;
+	ssize_t ret;
+
+	if (!buf)
+		return -ENOMEM;
+
+	if (copy_from_user(buf, ubuf, buf_size)) {
+		ret = -EFAULT;
+		goto err;
+	}
+
+	if (kstrtoint(buf, 0, &sta_aid)) {
+		ret = -EINVAL;
+		goto err;
+	}
+
+	if ((sta_aid <= 0) || (sta_aid > SYSADPT_MAX_STA_SC4)) {
+		wiphy_warn(priv->hw->wiphy,
+			   "station aid is exceeding the limit %d\n", sta_aid);
+		ret = -EINVAL;
+		goto err;
+	}
+
+	priv->sta_aid = sta_aid;
+	ret = count;
+
+err:
 	free_page(addr);
 	return ret;
 }
 
 MWLWIFI_DEBUGFS_FILE_READ_OPS(info);
+MWLWIFI_DEBUGFS_FILE_READ_OPS(tx_status);
+MWLWIFI_DEBUGFS_FILE_READ_OPS(rx_status);
 MWLWIFI_DEBUGFS_FILE_READ_OPS(vif);
 MWLWIFI_DEBUGFS_FILE_READ_OPS(sta);
 MWLWIFI_DEBUGFS_FILE_READ_OPS(ampdu);
+MWLWIFI_DEBUGFS_FILE_READ_OPS(stnid);
 MWLWIFI_DEBUGFS_FILE_READ_OPS(device_pwrtbl);
-MWLWIFI_DEBUGFS_FILE_OPS(tx_desc);
 MWLWIFI_DEBUGFS_FILE_OPS(dfs_channel);
 MWLWIFI_DEBUGFS_FILE_OPS(dfs_radar);
 MWLWIFI_DEBUGFS_FILE_OPS(thermal);
 MWLWIFI_DEBUGFS_FILE_OPS(regrdwr);
+MWLWIFI_DEBUGFS_FILE_OPS(ratetable);
 
 void mwl_debugfs_init(struct ieee80211_hw *hw)
 {
@@ -838,15 +943,18 @@ void mwl_debugfs_init(struct ieee80211_hw *hw)
 		return;
 
 	MWLWIFI_DEBUGFS_ADD_FILE(info);
+	MWLWIFI_DEBUGFS_ADD_FILE(tx_status);
+	MWLWIFI_DEBUGFS_ADD_FILE(rx_status);
 	MWLWIFI_DEBUGFS_ADD_FILE(vif);
 	MWLWIFI_DEBUGFS_ADD_FILE(sta);
 	MWLWIFI_DEBUGFS_ADD_FILE(ampdu);
+	MWLWIFI_DEBUGFS_ADD_FILE(stnid);
 	MWLWIFI_DEBUGFS_ADD_FILE(device_pwrtbl);
-	MWLWIFI_DEBUGFS_ADD_FILE(tx_desc);
 	MWLWIFI_DEBUGFS_ADD_FILE(dfs_channel);
 	MWLWIFI_DEBUGFS_ADD_FILE(dfs_radar);
 	MWLWIFI_DEBUGFS_ADD_FILE(thermal);
 	MWLWIFI_DEBUGFS_ADD_FILE(regrdwr);
+	MWLWIFI_DEBUGFS_ADD_FILE(ratetable);
 }
 
 void mwl_debugfs_remove(struct ieee80211_hw *hw)
